from setuptools import setup, find_packages

setup(
    name="tomorrow3",
    version="1.1.0",
    author="Daniel Lupu",
    author_email="lupu.daniel.f@gmail.com",
    packages=find_packages(),
    license="MIT License (See LICENSE)",
    url="https://github.com/dflupu/tomorrow3",
    description="simplified tomorrow for python3"
)
